#
# mvfs_log_scrubber.pl - perl script to clean out old mvfs log files.
#
# ------------------------------------------------------------------
# | Copyright Unpublished, Atria Software, Inc.  All Rights        |
# | Reserved.  This software contains proprietary and confidential |
# | information of Atria and its suppliers.  Use, disclosure or    |
# | reproduction is prohibited without the prior express written   |
# | consent of Atria.                                              |
# ------------------------------------------------------------------
#
# Revision history:
# becker                12/27/94	created

#
# perl script to clean out old mvfs log files.
# also remove older files until the available disk space
# is within $DSKSPC
#

use Win32::TieRegistry;

#
# remove all log file over $DAYS old and then ...
#
$DAYS=7 ;

#
# keep removing log files until free disk space is over $DSKSPC
#
$DSKSPC = 10 ;				# MB
$DSKSPC = $DSKSPC * 1000 * 1000 ;	# bytes

$DEBUG = "true" if $ARGV[0] =~ /^-[Dd]/;	# -d for debugging

###########################################################################
# get the date $DAYS days ago in logdir format ie: 19940427
#
sub Get_oldest {
    $secs = time ;
    $secs -= 86400 * $DAYS ; # seconds in a day * days
    ($sec,$min,$hour24,$mday,$mon,$yr,$wday,$yday,$isdst) = localtime($secs);
    $yr += 1900;
    $mon++;
    $oldest = sprintf("%04d%02d%02d", $yr, $mon, $mday) ;

    print "$DAYS days ago is (in logdir format) : $oldest\n" if $DEBUG ;
}

###########################################################################
# get the MVFS logdir from the NT registry
#
sub Get_logdir {
    my $Name = 'ulogdir';
    my $Type;
    my $ulogdir_rgy_key = "LMachine\\SYSTEM\\CurrentControlSet\\Services\\MVFS\\Parameters";
    my $Key =  Win32::TieRegistry->new($ulogdir_rgy_key,{Access=>'KEY_READ'})
	or die "Get_logdir: $^E $ulogdir_rgy_key";
    ($logdir,$Type) = $Key->GetValue($Name) 
	or die "Get_logdir: $^E $Name";

    $logdir =~ s-.*(.:.*)-\1- ;

    print "The logdir registry value is: $logdir \n" if $DEBUG ;
}

###########################################################################
# check available disk space
#
sub Check_dskspc {
    open(DIR, "cmd /c dir|");
    while (<DIR>) {
	    $free = $_ ; #really only keep the last line of output..
    }
    $free =~ s/\D*//g ;	# removes all non-numeric chars

    print "FREE disk space = $free \n" if $DEBUG ;
}

###########################################################################
# remove all normal log file names with a date previous to the oldest
# allowed (before $DAYS days ago )
#
sub Rm_old {
    opendir(DIR, ".");
    foreach (grep(/.log$/i, readdir(DIR))) {	# *.log in 'pwd'
	    ( $fdate = $_ ) =~ s/.log$//i ;	# filename without .log
	    if ( $fdate =~ m/[0-9]{8}/  &&  $fdate < $oldest ) {
		unlink ("$_" ) ||
		    warn "Error: Could not unlink $_: $!\n" ;
		print "Removing $_ ... old\n" if $DEBUG ;
	    }
    }
    closedir(DIR);
}
###########################################################################
# remove additional logfiles until free disk space is over $DSKSPC
#
sub Rm_for_space {

    while ( "$free" < "$DSKSPC" && "$DAYS" > 1 ) {
	if ( -f "$oldest.log" ) {
	    unlink ("$oldest.log") ||
	    	warn "Error: Could not unlink $oldest.log : $!\n" ;
	    print "Removing $oldest.log ... $free < $DSKSPC\n" if $DEBUG ;
	    &Check_dskspc ;
	}
	$DAYS-- ;
	&Get_oldest ;
    }
}

###########################################################################
# Main
#

&Get_oldest ;
&Get_logdir ;

chdir "$logdir" ||
	die "Can not chdir into $logdir : $! \n" ;

&Check_dskspc ;
&Rm_old ;
&Rm_for_space ;

__END__
    ;
